@@ -13,9 +13,9 @@ $WGET = "/usr/bin/wget";
 $LYNX = "NO";
 #$SED = "/bin/sed";
 $GREP = "/bin/grep";
-$RECODE = "NO"; #"/usr/bin/recode"; -- dont use recode, it is not widely available
+$RECODE = "NO"; #"NO"; -- dont use recode, it is not widely available
 # Directories
-$prefix="/home/chs/usr";
+$prefix="/home/cs/usr";
 $datadir="${prefix}/share";
 $pkgdatadir="$datadir/ktoblzcheck";
 $BANKDATADIR="${pkgdatadir}";
