@@ -1519,7 +1519,7 @@ AccountNumberCheck::Result method_D3(const int *account, int *weight) {
 AccountNumberCheck::Result method_D4(const int *account, int *weight) {
     // note this is a slightly modified version of the old method D1
     if (( account[0] >= 0 && account[0] <= 2 ) || ( account[0] >= 6 && account[0] <= 8 ))
-        return AccountNumberCheck::ERROR;
+	return AccountNumberCheck::ERROR;
     // note: from here on this method is quite similar to method_C6
     number2Array("2121212120", weight);
     int result  = algo03(10, weight, true, account, 0, 8);
@@ -1534,6 +1534,25 @@ AccountNumberCheck::Result method_D4(const int *account, int *weight) {
 	return AccountNumberCheck::ERROR;
 }
 
+// new method D5 valid from December 6th, 2010, checked with Bundesbank-Testnumbers
+AccountNumberCheck::Result method_D5(const int *account, int *weight) {
+    if ( account[2] == 9 && account[3] == 9 ) {
+	// variant 1: like method_06, but with different weight
+	number2Array("0087654320", weight);
+	return algo01(11, weight, false, 10, account);
+    } else {
+	number2Array("0007654320", weight);
+	// variant 2: like method_06, but with different weight
+	if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account) )
+	    return AccountNumberCheck::OK;
+	// variant 3
+	if (AccountNumberCheck::OK == algo02(7, weight, 10, account, 3, 8) )
+	    return AccountNumberCheck::OK;
+	// variant 4
+	return algo02(10, weight, 10, account, 3, 8);
+    }
+}
+
 struct method_func_s {
     const char *str;
     AccountNumberCheck::MethodFunc func;
@@ -1670,6 +1689,7 @@ const struct method_func_s cb_funcs[] = {
   { "D2", method_D2},
   { "D3", method_D3},
   { "D4", method_D4},
+  { "D5", method_D5},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
